"""
Contains a representation of GitHub users.
"""
from IGitt.GitHub import GitHubMixin, GH_INSTANCE_URL
from IGitt.Interfaces.User import User


class GitHubUser(GitHubMixin, User):
    """
    A GitHub user, e.g. sils :)
    """

    def __init__(self, token, username):
        self._token = token
        self._url = '/users/' + username
        self._username = username

    @property
    def username(self):
        """
        Retrieves the login for the user.
        """
        return self._username

    @property
    def identifier(self):
        """
        Gets a unique id for the user that never changes.
        """
        return self.data['id']

    @property
    def url(self):
        """
        The web URL for the user.
        """
        return GH_INSTANCE_URL + '/' + self.username



"""
Holds the User class representing users on such a platform.
"""
from IGitt.Interfaces import IGittObject


class User(IGittObject):
    """
    Represents a user on GitHub/Lab. If you want to uniquely identify a user,
    use the `id` property as the id will never change while the username might.
    """

    @property
    def username(self) -> str:
        """
        The username of the user. Warning: this might change when the user
        renames himself!
        """
        raise NotImplementedError

    @property
    def identifier(self) -> int:
        """
        A unique ID used to identify the user. This is also given in oauth
        records.
        """
        raise NotImplementedError
